@@ -8,17 +8,25 @@ from future.utils import PY3
 
 import textwrap
 from subprocess import Popen, PIPE, check_output, STDOUT
+from numbers import Integral
 import unittest
 
 
 class TestBuiltins(unittest.TestCase):
-    def test_int(self):
+    @unittest.expectedFailure
+    def test_isinstance_int(self):
         """
         Redefining ``int`` to ``long`` on Py2 would make this
         test fail:
         """
         self.assertTrue(isinstance(0, int))
 
+    def test_isinstance_Integral(self):
+        """
+        Tests the preferred alternative to the above
+        """
+        self.assertTrue(isinstance(0, Integral))
+
     @unittest.expectedFailure   # Py2's long doesn't inherit from int!
     def test_long(self):
         self.assertEqual(isinstance(10**100, int))
@@ -45,7 +53,7 @@ class TestBuiltins(unittest.TestCase):
         self.assertEqual(round(123.5, 1), 123.5)
 
         self.assertTrue(isinstance(round(123.5, 0), float))
-        self.assertTrue(isinstance(round(123.5), int))
+        self.assertTrue(isinstance(round(123.5), Integral))
 
     @unittest.skip('negative ndigits not implemented yet')
     def test_round_negative_ndigits(self):
