@@ -1,15 +1,12 @@
 """
 This tests whether
 
-    from future import *
-
-and
-
     from future.builtins import *
 
-work as expected. They should NOT introduce namespace pollution. On Python 3,
-this should have precisely no effect whatsoever. On Python 2, this should not
-introduce any new symbols, but merely shadow some of the builtins.
+works as expected:
+- This should NOT introduce namespace pollution on Py3.
+- On Python 2, this should not introduce any symbols that aren't in
+  __builtin__.
 
 """
 
@@ -23,28 +20,13 @@ from future import utils
 original_locals = set(copy.copy(locals()))
 original_globals = set(copy.copy(globals()))
 new_names = {'original_locals', 'original_globals', 'new_names'}
-from future import *
 from future.builtins import *
 new_locals = set(copy.copy(locals())) - new_names - original_locals
 new_globals = set(copy.copy(globals())) - new_names - original_globals - \
               {'new_locals'}
 
-# from future.tests import (test_common_iterators,
-#                           test_super,
-#                           test_standard_library_renames,
-#                           test_str_is_unicode)
 
-# class TestImportStar(test_common_iterators.TestIterators,
-#                      test_super.TestSuper,
-#                      test_standard_library_renames.TestStandardLibraryRenames,
-#                      test_str_is_unicode.TestStrIsUnicode):
-
-# @unittest.skip('Cannot use "from future import *" within unittest module')
 class TestImportStar(unittest.TestCase):
-    """
-    It would be nice if we could implement this as a subclass as above, to
-    avoid duplication. How?
-    """
     def test_namespace_pollution_locals(self):
         if utils.PY3:
             self.assertEqual(len(new_locals), 0,
