@@ -14,6 +14,9 @@ from libfuturize.fixer_util import touch_import_top
 
        
 class FixFutureBuiltins(BaseFix):
+    BM_compatible = True
+    PATTERN = "file_input"
+    run_order = 7
 
     def match(self, node):
         if node.type == syms.file_input:
